@@ -13,12 +13,14 @@ import (
 
 type SocksOption struct {
 	BaseOption
-	Users         AuthUsers     `inbound:"users,omitempty"`
-	UDP           bool          `inbound:"udp,omitempty"`
-	Certificate   string        `inbound:"certificate,omitempty"`
-	PrivateKey    string        `inbound:"private-key,omitempty"`
-	EchKey        string        `inbound:"ech-key,omitempty"`
-	RealityConfig RealityConfig `inbound:"reality-config,omitempty"`
+	Users          AuthUsers     `inbound:"users,omitempty"`
+	UDP            bool          `inbound:"udp,omitempty"`
+	Certificate    string        `inbound:"certificate,omitempty"`
+	PrivateKey     string        `inbound:"private-key,omitempty"`
+	ClientAuthType string        `inbound:"client-auth-type,omitempty"`
+	ClientAuthCert string        `inbound:"client-auth-cert,omitempty"`
+	EchKey         string        `inbound:"ech-key,omitempty"`
+	RealityConfig  RealityConfig `inbound:"reality-config,omitempty"`
 }
 
 func (o SocksOption) Equal(config C.InboundConfig) bool {
@@ -85,13 +87,15 @@ func (s *Socks) Listen(tunnel C.Tunnel) error {
 	for _, addr := range strings.Split(s.RawAddress(), ",") {
 		stl, err := socks.NewWithConfig(
 			LC.AuthServer{
-				Enable:        true,
-				Listen:        addr,
-				AuthStore:     s.config.Users.GetAuthStore(),
-				Certificate:   s.config.Certificate,
-				PrivateKey:    s.config.PrivateKey,
-				EchKey:        s.config.EchKey,
-				RealityConfig: s.config.RealityConfig.Build(),
+				Enable:         true,
+				Listen:         addr,
+				AuthStore:      s.config.Users.GetAuthStore(),
+				Certificate:    s.config.Certificate,
+				PrivateKey:     s.config.PrivateKey,
+				ClientAuthType: s.config.ClientAuthType,
+				ClientAuthCert: s.config.ClientAuthCert,
+				EchKey:         s.config.EchKey,
+				RealityConfig:  s.config.RealityConfig.Build(),
 			},
 			tunnel,
 			s.Additions()...,
